Create an init version of a network viewer

- rename O-RAN-Function to O-RAN-Object

Issue-ID: OAM-363
Change-Id: I113202688aa07c7c90de43d44a00e0e782c221b2
Signed-off-by: Martin Skorupski <martin.skorupski@highstreet-technologies.com>
diff --git a/code/network-generator/model/python/ORanFunction.py b/code/network-generator/model/python/ORanObject.py
similarity index 89%
rename from code/network-generator/model/python/ORanFunction.py
rename to code/network-generator/model/python/ORanObject.py
index 06a4c81..c028419 100644
--- a/code/network-generator/model/python/ORanFunction.py
+++ b/code/network-generator/model/python/ORanObject.py
@@ -15,7 +15,7 @@
 #!/usr/bin/python
 
 """
-An abstract Class for O-RAN Functions
+An abstract Class for O-RAN Objects
 """
 from abc import ABC, abstractmethod
 from typing import Dict
@@ -27,8 +27,8 @@
 from model.python.GeoLocation import GeoLocation
 
 
-# Define the "IORanFunction" interface
-class IORanFunction(ITop):
+# Define the "IORanObject" interface
+class IORanObject(ITop):
     def __init__(
         self,
         address: AddressType = None,
@@ -42,9 +42,9 @@
         self.url = url
 
 
-# Define an abstract O-RAN Function class
-class ORanFunction(ABC, Top, IORanFunction):
-    def __init__(self, of: IORanFunction = None, **kwargs):
+# Define an abstract O-RAN Object class
+class ORanObject(Top, IORanObject):
+    def __init__(self, of: IORanObject = None, **kwargs):
         super().__init__(**kwargs)
         self.address = of["address"] if of and "address" in of else None
         self.geoLocation = (